@@ -39,8 +39,6 @@
 #include "preferences.h"
 #include "scoreboard.h"
 #include "warp.h"
-#include "games-gridframe.h"
-#include "games-pause-action.h"
 #include "games-fullscreen-action.h"
 #include "games-scores.h"
 
@@ -57,7 +55,6 @@ GSettings *settings;
 GSettings *worm_settings[NUMWORMS];
 GtkWidget *window;
 GtkWidget *statusbar;
-GtkWidget *notebook;
 GtkWidget *chat = NULL;
 
 static const GamesScoresCategory scorecats[] = {
@@ -93,6 +90,8 @@ gint restart_id = 0;
 
 gint current_level;
 
+gboolean is_paused;
+
 static gint add_bonus_cb (gpointer data);
 
 static gint end_game_cb (GtkAction * action, gpointer data);
@@ -119,7 +118,7 @@ show_cursor (void)
 gint
 game_running (void)
 {
-  return (main_id || dummy_id || restart_id || games_pause_action_get_is_paused (GAMES_PAUSE_ACTION (pause_action)));
+  return (main_id || dummy_id || restart_id || is_paused);
 }
 
 /* Avoid a race condition where a redraw is attempted
@@ -227,7 +226,7 @@ configure_event_cb (GtkWidget *widget, GdkEventConfigure *event, gpointer data)
 static gboolean
 new_game_2_cb (GtkWidget * widget, gpointer data)
 {
-  if (!games_pause_action_get_is_paused (GAMES_PAUSE_ACTION (pause_action))) {
+  //if (!is_paused) {  //FIXME figure out why this should be here.
     if (!keyboard_id)
       keyboard_id = g_signal_connect (G_OBJECT (stage),
                                       "key-press-event",
@@ -241,7 +240,7 @@ new_game_2_cb (GtkWidget * widget, gpointer data)
                                     properties->gamespeed,
                                     (GSourceFunc) add_bonus_cb, NULL);
     }
-  }
+  //}
 
   dummy_id = 0;
 
@@ -277,7 +276,7 @@ new_game (void)
     gnibbles_worm_show (worms[i]);
   }
 
-  games_pause_action_set_is_paused (GAMES_PAUSE_ACTION (pause_action), FALSE);
+  is_paused = FALSE;
 
   if (restart_id) {
     g_source_remove (restart_id);
@@ -306,7 +305,9 @@ new_game_cb (GtkAction * action, gpointer data)
 static void
 pause_game_cb (GtkAction * action, gpointer data)
 {
-  if (games_pause_action_get_is_paused (GAMES_PAUSE_ACTION (action))) {
+  if (!is_paused) {  //If it's not currently paused, pause the game
+    is_paused = TRUE;
+    gtk_action_set_label (action, ("_Resume"));
     if (main_id || restart_id || dummy_id) {
       if (main_id) {
         g_source_remove (main_id);
@@ -322,7 +323,9 @@ pause_game_cb (GtkAction * action, gpointer data)
       }
     }
   }
-  else {
+  else {  //Resume the game
+    is_paused = FALSE;
+    gtk_action_set_label (action, ("_Pause"));
     dummy_id = g_timeout_add (500, (GSourceFunc) new_game_2_cb, NULL);
   }
 }
@@ -362,7 +365,7 @@ end_game (void)
   gtk_action_set_sensitive (new_game_action, TRUE);
   gtk_action_set_sensitive (preferences_action, TRUE);
 
-  games_pause_action_set_is_paused (GAMES_PAUSE_ACTION (pause_action), FALSE);
+  is_paused = FALSE;
 }
 
 static gboolean
@@ -582,6 +585,8 @@ static const GtkActionEntry action_entry[] = {
    G_CALLBACK (new_game_cb)},
   {"EndGame", NULL, N_("_End Game"), NULL, NULL,
    G_CALLBACK (end_game_cb)},
+  {"Pause", NULL, N_("_Pause"), NULL, NULL,
+   G_CALLBACK (pause_game_cb)},
   {"Quit", GTK_STOCK_QUIT, NULL, NULL, NULL, G_CALLBACK (quit_cb)},
   {"Preferences", GTK_STOCK_PREFERENCES, NULL, NULL, NULL,
    G_CALLBACK (gnibbles_preferences_cb)},
@@ -630,9 +635,7 @@ create_menus (GtkUIManager * ui_manager)
   new_game_action = gtk_action_group_get_action (action_group, "NewGame");
   scores_action = gtk_action_group_get_action (action_group, "Scores");
   end_game_action = gtk_action_group_get_action (action_group, "EndGame");
-  pause_action = GTK_ACTION (games_pause_action_new ("Pause"));
-  g_signal_connect (G_OBJECT (pause_action), "state-changed", G_CALLBACK (pause_game_cb), NULL);
-  gtk_action_group_add_action_with_accel (action_group, pause_action, NULL);
+  pause_action = gtk_action_group_get_action (action_group, "Pause");
 
   preferences_action = gtk_action_group_get_action (action_group,
                                                     "Preferences");
@@ -645,8 +648,8 @@ static void
 setup_window (void)
 {
   GtkWidget *vbox;
-  GtkWidget *packing;
   GtkWidget *menubar;
+  GtkWidget *packing;
 
   GtkUIManager *ui_manager;
   GtkAccelGroup *accel_group;
@@ -682,9 +685,6 @@ setup_window (void)
 
   ui_manager = gtk_ui_manager_new ();
   create_menus (ui_manager);
-  notebook = gtk_notebook_new ();
-  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
-  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 
   accel_group = gtk_ui_manager_get_accel_group (ui_manager);
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
@@ -693,20 +693,22 @@ setup_window (void)
 
   gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
 
-  packing = games_grid_frame_new (BOARDWIDTH, BOARDHEIGHT);
-  gtk_widget_show (packing);
-
-  gtk_container_add (GTK_CONTAINER (packing), clutter_widget);
-
   g_signal_connect (G_OBJECT (clutter_widget), "configure_event",
                     G_CALLBACK (configure_event_cb), NULL);
 
   g_signal_connect (G_OBJECT (window), "focus_out_event",
                     G_CALLBACK (show_cursor_cb), NULL);
 
-  gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
-  gtk_notebook_append_page (GTK_NOTEBOOK (notebook), packing, NULL);
-  gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), MAIN_PAGE);
+  packing = gtk_aspect_frame_new (NULL,
+                        0.5,
+                        0.5,
+                        1.38,   //between 1.398176292 and 1.388888889
+                        FALSE);
+
+
+  gtk_container_add( GTK_CONTAINER(packing), clutter_widget); 
+
+  gtk_box_pack_start (GTK_BOX (vbox), packing, FALSE, TRUE, 0);
 
   statusbar = gtk_statusbar_new ();
   gtk_box_pack_start (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
